==> ooga04_speaker-0.0.10.tar.gz: android/src/main/java/ooga/sh4/jp/speaker/Ooga04SpeakerPlugin.java <==
package ooga.sh4.jp.speaker;

import android.content.Context;
import android.net.Uri;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/** Ooga04SpeakerPlugin */
public class Ooga04SpeakerPlugin implements MethodCallHandler, Ooga04Speaker.SpeakEndListener {

  private static Context context;
  private final MethodChannel channel;
  private List<String> playList;

  /** Plugin registration. */
  public static void registerWith(Registrar registrar) {
    context = registrar.context();
    MethodChannel channel = new MethodChannel(registrar.messenger(), "ooga04/speaker");
    channel.setMethodCallHandler(new Ooga04SpeakerPlugin(channel));
  }

  private Ooga04SpeakerPlugin(MethodChannel channel) {
    this.channel = channel;
  }

  @Override
  public void onMethodCall(MethodCall call, Result result) {
    if (call.method.equals("play")) {
      String resourceUri = call.argument("resourceUri");
      playList = new ArrayList<>();
      playList.add(resourceUri);

      if (play()) {
        result.success("start MediaPlayer");
      } else {
        result.error("failed to start MediaPlayer", resourceUri, null);
      }
    } else if (call.method.equals("plays")) {
      playList = new ArrayList<>();
      List<String> resourceUris = call.argument("resourceUris");
      playList.addAll(resourceUris);

      if (play()) {
        result.success("start MediaPlayer");
      } else {
        result.error("failed to start MediaPlayer", resourceUris.toString(), null);
      }
    } else {
      result.notImplemented();
    }
  }

  // Play a single file
  private boolean play() {
    Ooga04Speaker speaker = new Ooga04Speaker(this);
    String resourceUri = playList.get(0);
    playList.remove(0);
    try {
      if (!(resourceUri.startsWith("http://") || resourceUri.startsWith("https://"))) {
        Uri uri = Uri.parse("android.resource://" + context.getPackageName() + "/raw/" + resourceUri);
        speaker.play(context, uri);
      } else {
        speaker.play(resourceUri);
      }
      return true;
    } catch (IOException e) {
      e.printStackTrace();
      return false;
    }
  }

  @Override
  public void onSpeakEnd() {
    if (playList.size() > 0) {
      if (!play()) {
        channel.invokeMethod("onSpeakEnd", null);
      }
    } else {
      channel.invokeMethod("onSpeakEnd", null);
    }
  }
}

==> ooga04_speaker-0.0.12.tar.gz: android/src/main/java/ooga/sh4/jp/speaker/Ooga04SpeakerPlugin.java <==
package ooga.sh4.jp.speaker;

import android.content.res.AssetFileDescriptor;
import android.content.res.AssetManager;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/** Ooga04SpeakerPlugin */
public class Ooga04SpeakerPlugin implements MethodCallHandler, Ooga04Speaker.SpeakEndListener {

  private static Registrar registrar;
  // private static Context context;
  private final MethodChannel channel;
  private List<String> playList;

  /** Plugin registration. */
  public static void registerWith(Registrar registrar) {
    Ooga04SpeakerPlugin.registrar = registrar;

    MethodChannel channel = new MethodChannel(registrar.messenger(), "ooga04/speaker");
    channel.setMethodCallHandler(new Ooga04SpeakerPlugin(channel));
  }

  private Ooga04SpeakerPlugin(MethodChannel channel) {
    this.channel = channel;
  }

  @Override
  public void onMethodCall(MethodCall call, Result result) {
    if (call.method.equals("play")) {
      String resourceUri = call.argument("resourceUri");
      playList = new ArrayList<>();
      playList.add(resourceUri);

      if (play()) {
        result.success("start MediaPlayer");
      } else {
        result.error("failed to start MediaPlayer", resourceUri, null);
      }
    } else if (call.method.equals("plays")) {
      playList = new ArrayList<>();
      List<String> resourceUris = call.argument("resourceUris");
      playList.addAll(resourceUris);

      if (play()) {
        result.success("start MediaPlayer");
      } else {
        result.error("failed to start MediaPlayer", resourceUris.toString(), null);
      }
    } else {
      result.notImplemented();
    }
  }

  // Play a single file
  private boolean play() {
    Ooga04Speaker speaker = new Ooga04Speaker(this);
    String resourceUri = playList.get(0);
    playList.remove(0);
    try {
      if (!(resourceUri.startsWith("http://") || resourceUri.startsWith("https://"))) {
        AssetManager assetManager = registrar.context().getAssets();
        String key = registrar.lookupKeyForAsset("audios/" + resourceUri);
        AssetFileDescriptor fd = assetManager.openFd(key);
        speaker.play(fd);

      } else {
        speaker.play(resourceUri);
      }
      return true;
    } catch (IOException e) {
      e.printStackTrace();
      return false;
    }
  }

  @Override
  public void onSpeakEnd() {
    if (playList.size() > 0) {
      if (!play()) {
        channel.invokeMethod("onSpeakEnd", null);
      }
    } else {
      channel.invokeMethod("onSpeakEnd", null);
    }
  }
}
